@@ -34,9 +34,7 @@ def cmpElements(lhs, rhs):
 
 
 class DictMethodEntityHelper(object):
-    """Helper class implements methods supporting entity-level item and category methods in the RCSB dictionary extension.
-
-    """
+    """Helper class implements methods supporting entity-level item and category methods in the RCSB dictionary extension."""
 
     def __init__(self, **kwargs):
         """
@@ -53,7 +51,9 @@ class DictMethodEntityHelper(object):
         self.__commonU = rP.getResource("DictMethodCommonUtils instance") if rP else None
         self.__dApi = rP.getResource("Dictionary API instance (pdbx_core)") if rP else None
         #
-        self.__useSiftsAlign = True
+        self.__useSiftsAlign = rP.getReferenceSequenceAlignmentOpt() == "SIFTS"
+        # logger.info("SIFTS alignment option %r", self.__useSiftsAlign)
+        #
         self.__ssP = None
         if self.__useSiftsAlign:
             self.__ssP = rP.getResource("SiftsSummaryProvider instance") if rP else None
@@ -364,8 +364,52 @@ class DictMethodEntityHelper(object):
             logger.exception("For %s  %s failing with %s", dataContainer.getName(), catName, str(e))
         return False
 
+    def __salvageMissingTaxonomy(self, dataContainer, **kwargs):
+        """Add missing taxonomy identifiers using scientific name as a surogate.
+
+        Args:
+            dataContainer (obj): data container object
+
+        Returns:
+            bool: True for success or False otherwise
+        """
+        #
+        ok = False
+        try:
+            rP = kwargs.get("resourceProvider")
+            taxU = rP.getResource("TaxonomyProvider instance") if rP else None
+            # "pdbx_gene_src_scientific_name" "pdbx_gene_src_ncbi_taxonomy_id"
+            for catName, atSn, atTaxId in [
+                ("entity_src_gen", "pdbx_gene_src_scientific_name", "pdbx_gene_src_ncbi_taxonomy_id"),
+                ("entity_src_gen", "pdbx_host_org_scientific_name", "pdbx_host_org_ncbi_taxonomy_id"),
+                ("entity_src_nat", "pdbx_organism_scientific", "pdbx_ncbi_taxonomy_id"),
+                ("entity_src_syn", "organism_scientific", "ncbi_taxonomy_id"),
+            ]:
+                if dataContainer.exists(catName):
+                    sObj = dataContainer.getObj(catName)
+                    for ii in range(sObj.getRowCount()):
+                        taxId = sObj.getValueOrDefault(atTaxId, ii, defaultValue=None)
+                        #
+                        if taxId:
+                            continue
+                        sn = sObj.getValueOrDefault(atSn, ii, defaultValue=None)
+                        if sn:
+                            taxId = taxU.getTaxId(sn)
+                            if taxId:
+                                if not sObj.hasAttribute(atTaxId):
+                                    sObj.appendAttribute(atTaxId)
+                                logger.info("%s salvaged taxId %r using %r", dataContainer.getName(), taxId, sn)
+                                sObj.setValue(str(taxId), atTaxId, ii)
+                            else:
+                                logger.warning("%s taxId salvage fails for scientific name %s", dataContainer.getName(), sn)
+            ok = True
+        except Exception as e:
+            logger.exception("Failing for %r with %s", dataContainer.getName(), str(e))
+
+        return ok
+
     def filterSourceOrganismDetails(self, dataContainer, catName, **kwargs):
-        """ Load new categories rcsb_entity_source_organism and rcsb_entity_host_organism
+        """Load new categories rcsb_entity_source_organism and rcsb_entity_host_organism
          and add related source flags in the entity category.
 
         Args:
@@ -428,6 +472,10 @@ class DictMethodEntityHelper(object):
             # if there is no source information then exit
             if not (dataContainer.exists("entity_src_gen") or dataContainer.exists("entity_src_nat") or dataContainer.exists("pdbx_entity_src_syn")):
                 return False
+            #
+            # Try to supply missing taxIds
+            self.__salvageMissingTaxonomy(dataContainer, **kwargs)
+            #
             # Create the new target category
             if not dataContainer.exists(catName):
                 dataContainer.append(DataCategory(catName, attributeNameList=self.__dApi.getAttributeNameList(catName)))
@@ -640,6 +688,7 @@ class DictMethodEntityHelper(object):
                     logger.debug("%r entity %r - UPDATED %r %r", sType, entityId, atL, v)
                     iRow += 1
             # -------------------------------------------------------------------------
+            # -------------------------------------------------------------------------
             # Update entity attributes
             #    _entity.rcsb_multiple_source_flag
             #    _entity.rcsb_source_part_count
@@ -647,18 +696,20 @@ class DictMethodEntityHelper(object):
                 if not eObj.hasAttribute(atName):
                     eObj.appendAttribute(atName)
             #
+            taxCountTotal = 0
             for ii in range(eObj.getRowCount()):
                 entityId = eObj.getValue("id", ii)
                 cFlag = "Y" if partCountD[entityId] > 1 else "N"
                 eObj.setValue(partCountD[entityId], "rcsb_source_part_count", ii)
                 eObj.setValue(cFlag, "rcsb_multiple_source_flag", ii)
-                if entityId in entityTaxIdD:
-                    eObj.setValue(len(entityTaxIdD[entityId]), "rcsb_source_taxonomy_count", ii)
+                taxCount = len(entityTaxIdD[entityId]) if entityId in entityTaxIdD else 0
+                eObj.setValue(taxCount, "rcsb_source_taxonomy_count", ii)
+                taxCountTotal += taxCount
 
-            logger.debug("Entry taxonomy count is %d", len(entryTaxIdD))
+            logger.debug("Entities with taxonomies %d entry total taxonomy count is %d", len(entryTaxIdD), taxCountTotal)
             if dataContainer.exists("rcsb_entry_info"):
                 eiObj = dataContainer.getObj("rcsb_entry_info")
-                eiObj.setValue(len(entryTaxIdD), "polymer_entity_taxonomy_count", 0)
+                eiObj.setValue(taxCountTotal, "polymer_entity_taxonomy_count", 0)
             #
             return True
         except Exception as e:
@@ -666,7 +717,7 @@ class DictMethodEntityHelper(object):
         return False
 
     def __addEntityCompIds(self, dataContainer):
-        """ Add entity_id and BIRD codes to selected categories.
+        """Add entity_id and BIRD codes to selected categories.
 
         Args:
             dataContainer (object): mmif.api.DataContainer object instance
@@ -706,7 +757,7 @@ class DictMethodEntityHelper(object):
         return False
 
     def __addBirdEntityIds(self, dataContainer):
-        """ Add entity_id and BIRD codes to selected categories.
+        """Add entity_id and BIRD codes to selected categories.
 
         Args:
             dataContainer (object): mmif.api.DataContainer object instance
@@ -823,7 +874,7 @@ class DictMethodEntityHelper(object):
         return False
 
     def addStructRefSeqEntityIds(self, dataContainer, catName, **kwargs):
-        """ Add entity ids in categories struct_ref_seq and struct_ref_seq_dir instances.
+        """Add entity ids in categories struct_ref_seq and struct_ref_seq_dir instances.
 
         Args:
             dataContainer (object): mmif.api.DataContainer object instance
@@ -878,7 +929,7 @@ class DictMethodEntityHelper(object):
         return False
 
     def buildEntityPolyInfo(self, dataContainer, catName, **kwargs):
-        """ Build category rcsb_entity_poly_info and supplement category entity_poly.
+        """Build category rcsb_entity_poly_info and supplement category entity_poly.
 
         Args:
             dataContainer (object): mmif.api.DataContainer object instance
@@ -1021,7 +1072,7 @@ class DictMethodEntityHelper(object):
         return False
 
     def addEntityMisc(self, dataContainer, catName, atName, **kwargs):
-        """ Add consolidated enzyme classification macromolecule names to the entity category.
+        """Add consolidated enzyme classification macromolecule names to the entity category.
 
         Args:
             dataContainer (object): mmif.api.DataContainer object instance
@@ -1190,8 +1241,7 @@ class DictMethodEntityHelper(object):
         return False
 
     def __cleanupCsv(self, tL):
-        """ Ad hoc cleanup function for comma separated lists with embedded punctuation
-        """
+        """Ad hoc cleanup function for comma separated lists with embedded punctuation"""
         rL = []
         try:
             key_paths = functools.cmp_to_key(cmpElements)
@@ -1226,13 +1276,13 @@ class DictMethodEntityHelper(object):
         return atSL, atL
 
     def __normalizeCsvToList(self, entryId, colL, separator=","):
-        """ Normalize a row containing some character delimited fields.
+        """Normalize a row containing some character delimited fields.
 
-            Expand list of uneven lists into unifornm list of lists.
-            Only two list lengths are logically supported: 1 and second
-            maximum length.
+        Expand list of uneven lists into unifornm list of lists.
+        Only two list lengths are logically supported: 1 and second
+        maximum length.
 
-            returns: list of expanded rows or the original input.
+        returns: list of expanded rows or the original input.
 
         """
         tcL = []
@@ -1289,16 +1339,14 @@ class DictMethodEntityHelper(object):
         return rL
 
     def __stripWhiteSpace(self, val):
-        """ Remove all white space from the input value.
-
-        """
+        """Remove all white space from the input value."""
         if val is None:
             return val
         return self.__wsPattern.sub("", val)
 
     #
     def __getTargetComponentFeatures(self, dataContainer):
-        """ Get targeted components-
+        """Get targeted components-
 
         Args:
             dataContainer ([type]): [description]
@@ -1325,7 +1373,7 @@ class DictMethodEntityHelper(object):
 
     #
     def __getBirdFeatures(self, dataContainer):
-        """ Get type and class Bird annotations -
+        """Get type and class Bird annotations -
 
         Args:
             dataContainer ([type]): [description]
@@ -1403,7 +1451,7 @@ class DictMethodEntityHelper(object):
         return fTypeL
 
     def buildEntityFeatureSummary(self, dataContainer, catName, **kwargs):
-        """ Build category rcsb_entity_feature_summary (UPDATED)
+        """Build category rcsb_entity_feature_summary (UPDATED)
 
         Example:
 
@@ -1492,7 +1540,7 @@ class DictMethodEntityHelper(object):
         return True
 
     def buildEntityFeatures(self, dataContainer, catName, **kwargs):
-        """ Build category rcsb_entity_feature ...
+        """Build category rcsb_entity_feature ...
 
         Example:
             loop_
@@ -1650,7 +1698,7 @@ class DictMethodEntityHelper(object):
         return False
 
     def addTypedEntityCategories(self, dataContainer, blockName, **kwargs):
-        """ Slice common entity categories into type specific entity categories.
+        """Slice common entity categories into type specific entity categories.
 
         Args:
             dataContainer (object): mmif.api.DataContainer object instance
@@ -1700,7 +1748,7 @@ class DictMethodEntityHelper(object):
         return False
 
     def addTypedEntityFeatureCategories(self, dataContainer, blockName, **kwargs):
-        """ Slice common entity categories into type specific entity categories.
+        """Slice common entity categories into type specific entity categories.
 
         Args:
             dataContainer (object): mmif.api.DataContainer object instance
@@ -1714,7 +1762,11 @@ class DictMethodEntityHelper(object):
         try:
             if not (dataContainer.exists("entry") and dataContainer.exists("entity")):
                 return False
-            if dataContainer.exists("rcsb_polymer_entity_feature") or dataContainer.exists("rcsb_nonpolymer_entity_feature") or dataContainer.exists("rcsb_branched_entity_feature"):
+            if (
+                dataContainer.exists("rcsb_polymer_entity_feature")
+                or dataContainer.exists("rcsb_nonpolymer_entity_feature")
+                or dataContainer.exists("rcsb_branched_entity_feature")
+            ):
                 return True
             # -----
             categoryMapD = {
@@ -1759,7 +1811,7 @@ class DictMethodEntityHelper(object):
         return False
 
     def __sliceCategoriesByEntityType(self, dataContainer, categoryMapD):
-        """ Slice common entity categories into type specific entity categories.
+        """Slice common entity categories into type specific entity categories.
 
         Args:
             dataContainer (object): mmif.api.DataContainer object instance
@@ -1822,7 +1874,7 @@ class DictMethodEntityHelper(object):
 
     #
     def buildEntityAnnotations(self, dataContainer, catName, **kwargs):
-        """ Build category rcsb_entity_annotation ...
+        """Build category rcsb_entity_annotation ...
 
         Example:
             loop_
